summaryrefslogtreecommitdiffstats
path: root/akregator/src/tagset.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tagset.h')
-rw-r--r--akregator/src/tagset.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/akregator/src/tagset.h b/akregator/src/tagset.h
index febb47d3..637fce50 100644
--- a/akregator/src/tagset.h
+++ b/akregator/src/tagset.h
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef AKREGATOR_TAGSET_H
@@ -44,13 +44,14 @@ class Tag;
@author Frank Osterfeld
*/
-class TagSet : public QObject
+class TagSet : public TQObject
{
friend class Tag;
Q_OBJECT
+ TQ_OBJECT
public:
- TagSet(TQObject* parent=0);
+ TagSet(TQObject* tqparent=0);
virtual ~TagSet();
/** adds a tag to the tag set. The tag set will emit signalTagAdded */
@@ -65,8 +66,8 @@ class TagSet : public QObject
/** returns @c true if this set tqcontains @c tag */
bool tqcontains(const Tag& tag) const;
- /** returns @c true if this set tqcontains a tag with a given ID */
- bool tqcontainsID(const TQString& id) const;
+ /** returns @c true if this set contains a tag with a given ID */
+ bool containsID(const TQString& id) const;
/** returns the tag with the given ID if the tag is element of the set, or a null tag if not */
Tag findByID(const TQString& id) const;